Getting started
---------------

Like many aspects of programming, it is necessary to learn the concepts of
object oriented programming before you can use them effectively.
You should approach this chapter as a way to learn some terms and concepts and work
through a few simple examples to lay a foundation for future learning.

The key outcome of this chapter is to have a basic understanding of how
objects are constructed and how they function and most importantly how
we make use of the capabilities of objects that are provided to us by Python
and Python libraries.